pub enum IdentityEvent {
StateChanged {
identity: AgentIdentity,
new_state: IdentityLifecycleState,
},
LeaseUpdated {
identity: AgentIdentity,
fencing_token: FencingToken,
},
LeaseLost {
identity: AgentIdentity,
},
CheckpointCompleted {
identity: AgentIdentity,
version: CheckpointVersion,
},
ResumeFallback {
identity: AgentIdentity,
reason: ResumeFallbackReason,
},
}Expand description
Events emitted for a specific identity, used by subscribe().
Variants
StateChanged
Lifecycle state changed.
LeaseUpdated
Lease acquired or renewed.
LeaseLost
Lease lost.
Fields

identity: AgentIdentityCheckpointCompleted
Checkpoint completed.
ResumeFallback
Resume could not reuse a persisted runtime binding and materialization fresh-spawned a member instead.