pub struct ContinuityRecord {
pub identity: AgentIdentity,
pub agent_runtime_id: AgentRuntimeId,
pub session_id: SessionId,
pub generation: ContinuityGeneration,
pub checkpoint_version: CheckpointVersion,
}Expand description
The authoritative continuity record for a durable agent identity.
Fields
identity: AgentIdentityagent_runtime_id: AgentRuntimeIdsession_id: SessionIdgeneration: ContinuityGenerationcheckpoint_version: CheckpointVersionTrait Implementations
Sourceimpl Clone for ContinuityRecord
impl Clone for ContinuityRecord
Sourcefn clone(&self) -> ContinuityRecord
fn clone(&self) -> ContinuityRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContinuityRecord
impl Debug for ContinuityRecord
Sourceimpl<'de> Deserialize<'de> for ContinuityRecord
impl<'de> Deserialize<'de> for ContinuityRecord
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ContinuityRecord
Sourceimpl PartialEq for ContinuityRecord
impl PartialEq for ContinuityRecord
Sourcefn eq(&self, other: &ContinuityRecord) -> bool
fn eq(&self, other: &ContinuityRecord) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ContinuityRecord
impl Serialize for ContinuityRecord
impl StructuralPartialEq for ContinuityRecord