TranscriptSource

Trait TranscriptSource 

pub trait TranscriptSource: Send + Sync {
    // Required method
    fn read<'life0, 'life1, 'async_trait>(
        &'life0 self,
        session_key: &'life1 str,
        from_index: u64,
    ) -> Pin<Box<dyn Future<Output = Result<Option<TranscriptSlice>, DistillerError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
}
How the engine reads persisted transcripts. The real implementation is SessionStoreTranscriptSource; tests supply scripted slices.

Required Methods

fn read<'life0, 'life1, 'async_trait>( &'life0 self, session_key: &'life1 str, from_index: u64, ) -> Pin<Box<dyn Future<Output = Result<Option<TranscriptSlice>, DistillerError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Messages from from_index to the current end of the persisted transcript; None when the session does not exist in the store.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors