pub struct CommitReceipt {
pub token: String,
pub applied_ops: usize,
pub memory_ids: Vec<MemoryId>,
}Expand description
Result of an atomic commit: the affected record id per applied op, in op
order (None for ops that touch no single record id — currently none).
Fields
token: Stringapplied_ops: usizememory_ids: Vec<MemoryId>Trait Implementations
Sourceimpl Clone for CommitReceipt
impl Clone for CommitReceipt
Sourcefn clone(&self) -> CommitReceipt
fn clone(&self) -> CommitReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommitReceipt
impl Debug for CommitReceipt
Sourceimpl<'de> Deserialize<'de> for CommitReceipt
impl<'de> Deserialize<'de> for CommitReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CommitReceipt
Sourceimpl PartialEq for CommitReceipt
impl PartialEq for CommitReceipt
Sourcefn eq(&self, other: &CommitReceipt) -> bool
fn eq(&self, other: &CommitReceipt) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CommitReceipt
impl Serialize for CommitReceipt
impl StructuralPartialEq for CommitReceipt