pub enum ScheduleValidationError {
EmptyScheduleId,
DuplicateScheduleId(String),
InvalidTickMs(u64),
InvalidInterval {
schedule_id: String,
interval: String,
},
InvalidTimezone {
schedule_id: String,
timezone: String,
},
LookbackBudgetExceeded {
schedule_id: String,
},
}Variants
EmptyScheduleId
DuplicateScheduleId(String)
InvalidTickMs(u64)
InvalidInterval
InvalidTimezone
LookbackBudgetExceeded
The total cron lookback work for this request exceeded
CRON_LOOKBACK_BUDGET_PER_REQUEST. Surfaced (rather than silently
stalling) when a request packs enough sparse crons to blow past the
per-request iteration ceiling — a soft-DoS guard.