Crate meerkat_mobkit

Crate meerkat_mobkit 

MobKit core — orchestration engine for the Meerkat multi-agent runtime.

Re-exports

pub use access::ACCESS_ACTIONS;
pub use access::AccessConfigError;
pub use access::AccessControlConfig;
pub use access::AccessController;
pub use access::AccessDecision;
pub use access::AccessEffect;
pub use access::AccessGroup;
pub use access::AccessPrincipal;
pub use access::AccessResource;
pub use access::AccessRule;
pub use access::AccessView;
pub use access::AgentResourceAttributes;
pub use access::evaluate_access;
pub use access::validate_access_config;
pub use auth::GATEWAY_PEER_KEY_FILE;
pub use auth::GatewayPeerKeyError;
pub use auth::GatewayPeerKeys;
pub use auth::Jwk;
pub use auth::JwksCache;
pub use auth::JwksCacheConfig;
pub use auth::JwksCacheError;
pub use auth::JwksDocument;
pub use auth::JwtHeaderView;
pub use auth::JwtValidationConfig;
pub use auth::JwtValidationError;
pub use auth::OidcContractError;
pub use auth::OidcDiscoveryDocument;
pub use auth::PubkeyDecodeError;
pub use auth::ValidatedJwt;
pub use auth::decode_pubkey_b64;
pub use auth::extract_hs256_shared_secret;
pub use auth::inspect_jwt_header;
pub use auth::parse_jwks_json;
pub use auth::parse_oidc_discovery_json;
pub use auth::select_jwk_for_token;
pub use auth::validate_jwt_locally;
pub use baseline::BaselineVerificationError;
pub use baseline::BaselineVerificationReport;
pub use baseline::DEFAULT_MEERKAT_REPO;
pub use baseline::REQUIRED_MEERKAT_SYMBOLS;
pub use baseline::verify_meerkat_baseline_symbols;
pub use blob_store::Base64BlobStoreAdapter;
pub use blob_store::BinaryBlobPayload;
pub use blob_store::BinaryBlobStore;
pub use blob_store::BinaryBlobStoreAdapter;
pub use blob_store::ObjectStoreBlobStore;
pub use config_convention::ConventionalPaths;
pub use console_aggregator::AllowAllConsoleVisibilityPolicy;
pub use console_aggregator::AppendDisposition;
pub use console_aggregator::AppendOutcome;
pub use console_aggregator::ConsoleAggregatorOptions;
pub use console_aggregator::ConsoleCursor;
pub use console_aggregator::ConsoleFrame;
pub use console_aggregator::ConsoleFrameSource;
pub use console_aggregator::ConsoleFrameSourceKind;
pub use console_aggregator::ConsoleFrameStatus;
pub use console_aggregator::ConsoleIdentityInspection;
pub use console_aggregator::ConsoleIdentityRecord;
pub use console_aggregator::ConsoleInteractionAccepted as ConsoleTimelineInteractionAccepted;
pub use console_aggregator::ConsoleLogError;
pub use console_aggregator::ConsoleLogResult;
pub use console_aggregator::ConsoleLogStore;
pub use console_aggregator::ConsoleReplayUnavailable;
pub use console_aggregator::ConsoleRuntimeRegistration;
pub use console_aggregator::ConsoleSendRequest;
pub use console_aggregator::ConsoleTimelineEvent;
pub use console_aggregator::ConsoleTimelineMode;
pub use console_aggregator::ConsoleTimelinePage;
pub use console_aggregator::ConsoleTimelineQuery;
pub use console_aggregator::ConsoleTimelineWindowPage;
pub use console_aggregator::ConsoleTimelineWindowQuery;
pub use console_aggregator::ConsoleVisibility;
pub use console_aggregator::ConsoleVisibilityPolicy;
pub use console_aggregator::HideImplicitDelegateMembersConsoleVisibilityPolicy;
pub use console_aggregator::InMemoryConsoleLogStore;
pub use console_aggregator::MobKitConsoleAggregator;
pub use console_aggregator::NewConsoleFrame;
pub use console_aggregator::ReplaySubscriptionEffect;
pub use console_aggregator::ReplaySubscriptionState;
pub use console_aggregator::ReplaySubscriptionTransition;
pub use console_aggregator::SendEffect;
pub use console_aggregator::SendState;
pub use console_aggregator::SendTransition;
pub use console_aggregator::SourceIngestionEffect;
pub use console_aggregator::SourceIngestionState;
pub use console_aggregator::SourceIngestionTransition;
pub use console_aggregator::SqliteConsoleLogStore;
pub use console_config::ConsoleActionsUiConfig;
pub use console_config::ConsoleAgentBadgeConfig;
pub use console_config::ConsoleAgentListConfig;
pub use console_config::ConsoleAgentSectionConfig;
pub use console_config::ConsoleAppearanceConfig;
pub use console_config::ConsoleBrandingConfig;
pub use console_config::ConsoleConfigError;
pub use console_config::ConsoleEnvironmentConfig;
pub use console_config::ConsoleLayoutConfig;
pub use console_config::ConsoleRailFilterPresetConfig;
pub use console_config::ConsoleRailUiConfig;
pub use console_config::ConsoleSidebarButtonConfig;
pub use console_config::ConsoleSidebarUiConfig;
pub use console_config::ConsoleUiConfig;
pub use console_config::load_console_ui_config_from_path_for_realm;
pub use console_config::load_console_ui_config_from_toml;
pub use console_config::load_console_ui_config_from_toml_for_realm;
pub use console_contracts::ConsoleIdentityEventEnvelope;
pub use console_contracts::ConsoleInteractionRejectedError;
pub use console_contracts::ReplayUnavailableError;
pub use decisions::AuthPolicy;
pub use decisions::AuthProvider;
pub use decisions::BigQueryNaming;
pub use decisions::ConsoleAccessRequest;
pub use decisions::ConsolePolicy;
pub use decisions::DecisionPolicyError;
pub use decisions::MetricsPolicy;
pub use decisions::REQUIRED_RELEASE_TARGETS;
pub use decisions::ReleaseMetadata;
pub use decisions::RuntimeOpsPolicy;
pub use decisions::enforce_console_route_access;
pub use decisions::load_trusted_mobkit_modules_from_toml;
pub use decisions::parse_release_metadata_json;
pub use decisions::validate_bigquery_naming;
pub use decisions::validate_release_metadata;
pub use decisions::validate_runtime_ops_policy;
pub use governance::validate_phase0_governance_contracts;Deprecated
pub use governance::GovernanceValidationError;
pub use governance::STRICT_TRACEABILITY_STATUSES;
pub use governance::validate_governance_contracts;
pub use governance::validate_governance_state;
pub use governance::validate_traceability_statuses;
pub use http_auth::auth_middleware;
pub use http_auth::with_auth_layer;
pub use http_console::ConsoleJsonState;
pub use http_console::console_frontend_app_js_handler;
pub use http_console::console_frontend_index_handler;
pub use http_console::console_frontend_router;
pub use http_console::console_json_handler;
pub use http_console::console_json_router;
pub use http_console::console_json_router_with_aggregator;
pub use http_console::console_json_router_with_aggregator_and_access;
pub use http_console::console_json_router_with_runtime;
pub use http_flow_editor::flow_editor_frontend_app_css_handler;
pub use http_flow_editor::flow_editor_frontend_app_js_handler;
pub use http_flow_editor::flow_editor_frontend_index_handler;
pub use http_flow_editor::flow_editor_frontend_router;
pub use http_flow_editor::flow_editor_frontend_vendor_js_handler;
pub use http_flow_editor::flow_editor_router;
pub use http_flow_editor::flow_editor_router_with_host_deploy;
pub use http_flow_editor::flow_editor_rpc_handler;
pub use http_flow_editor::flow_editor_rpc_handler_allowing_host_deploy;
pub use http_flow_editor::flow_editor_rpc_router;
pub use http_flow_editor::flow_editor_rpc_router_allowing_host_deploy;
pub use http_sse::AgentEventSubscribeFn;
pub use http_sse::MobEventSubscribeFn;
pub use http_sse::agent_event_sse;
pub use http_sse::agent_events_sse_router;
pub use http_sse::agent_events_sse_router_with_access;
pub use http_sse::mob_events_sse_router;
pub use http_sse::mob_events_sse_router_with_access;
pub use http_sse::mob_structural_events_sse_router;
pub use http_sse::mob_structural_events_sse_router_with_access;
pub use identity_first::AgentMemoryConfig;
pub use identity_first::AgentMemoryCustomizer;
pub use identity_first::AgentMemoryError;
pub use identity_first::AgentMemoryLlmWrites;
pub use identity_first::AgentMemoryOperatorScope;
pub use identity_first::AgentMemoryPerTurnInjection;
pub use identity_first::AgentMemoryProvider;
pub use identity_first::AgentMemoryRecallFailurePolicy;
pub use identity_first::AgentMemoryRecallRequest;
pub use identity_first::AgentMemoryRecord;
pub use identity_first::AgentMemoryRuntimeInjector;
pub use identity_first::AgentMemorySelection;
pub use identity_first::AuthoredWriteReceipt;
pub use identity_first::MEMORY_TOOL_NAME;
pub use identity_first::MarkdownAgentMemoryStore;
pub use identity_first::NewAgentMemory;
pub use memory::CompactionResetSink;
pub use memory::ConsolePrincipalOperatorResolver;
pub use memory::ContentTrustConfig;
pub use memory::DistillCause;
pub use memory::DistillerConfig;
pub use memory::DistillerEngine;
pub use memory::DreamOutcome;
pub use memory::DreamRun;
pub use memory::HygieneCause;
pub use memory::HygieneOutcome;
pub use memory::HygienistConfig;
pub use memory::HygienistEngine;
pub use memory::ManifestTier;
pub use memory::MemberAgentEventSink;
pub use memory::MemoryConflictBridge;
pub use memory::MemoryEventSink;
pub use memory::MemoryGatingBridge;
pub use memory::MemoryKind;
pub use memory::MemoryRecord;
pub use memory::MemoryScope;
pub use memory::MemorySpawnCustomizer;
pub use memory::MemoryTimelineEvent;
pub use memory::MobPurposeSource;
pub use memory::NewMemoryRecord;
pub use memory::OperatorResolver;
pub use memory::PromotionGateResolver;
pub use memory::RecordMeta;
pub use memory::SessionStoreEvidenceResolver;
pub use memory::SessionTaintTracker;
pub use memory::SqliteAgentMemoryStore;
pub use memory::StagedMemoryStore;
pub use memory::StagedMutationBatch;
pub use memory::StagedOp;
pub use memory::StewardConfig;
pub use memory::StewardEngine;
pub use memory::StewardTriggers;
pub use memory::TaintLlmWriteGate;
pub use memory::TaintObserverGuard;
pub use memory::TrustTier;
pub use memory::spawn_member_event_observer;
pub use memory::spawn_taint_observer;
pub use mob_handle_runtime::AfterCreateHook;
pub use mob_handle_runtime::CapabilityFlags;
pub use mob_handle_runtime::MobBootstrapOptions;
pub use mob_handle_runtime::MobBootstrapSpec;
pub use mob_handle_runtime::MobRuntime;
pub use mob_handle_runtime::MobRuntimeError;
pub use mob_handle_runtime::RealMobRuntime;
pub use mob_handle_runtime::SessionCreatedContext;
pub use mob_handle_runtime::SessionHook;
pub use mob_handle_runtime::member_entry_to_json;
pub use mob_handle_runtime::send_message_on_mob;
pub use mobpack::MOBPACK_MEDIA_TYPE;
pub use mobpack::MOBPACK_SCHEMA_VERSION;
pub use mobpack::MobpackDeployCommandResult;
pub use mobpack::MobpackDiagnostic;
pub use mobpack::MobpackDocument;
pub use mobpack::MobpackExportResult;
pub use mobpack::MobpackValidationResult;
pub use mobpack::deploy_command_preview;
pub use mobpack::export_mobpack;
pub use mobpack::import_mobpack;
pub use mobpack::mobpack_schema_response;
pub use mobpack::validate_mobpack;
pub use mocks::MockModuleProcess;
pub use mocks::MockProcessError;
pub use process::ProcessBoundaryError;
pub use process::run_process_json_line;
pub use protocol::ProtocolParseError;
pub use protocol::parse_module_event_line;
pub use protocol::parse_unified_event_line;
pub use rpc::CONSOLE_TIMELINE_REPLAY_UNAVAILABLE_CODE;
pub use rpc::IdentityFirstContext;
pub use rpc::JsonRpcError;
pub use rpc::JsonRpcRequest;
pub use rpc::JsonRpcResponse;
pub use rpc::MEMORY_BACKEND_UNAVAILABLE_CODE;
pub use rpc::MOB_EVENTS_STALE_CURSOR_CODE;
pub use rpc::MOBKIT_CONTRACT_VERSION;
pub use rpc::handle_console_ingress_json;
pub use rpc::handle_mobkit_rpc_json;
pub use rpc::handle_unified_rpc_json;
pub use rpc::RpcCapabilities;
pub use rpc::RpcCapabilitiesError;
pub use rpc::parse_rpc_capabilities;
pub use runtime::BaselineRuntimeError;
pub use runtime::BigQueryGcConfig;
pub use runtime::BigQuerySessionStoreAdapter;
pub use runtime::BigQuerySessionStoreError;
pub use runtime::ConfigResolutionError;
pub use runtime::ConsoleAgentLiveSnapshot;
pub use runtime::ConsoleLiveSnapshot;
pub use runtime::ConsoleModelCapabilities;
pub use runtime::ConsoleRestJsonRequest;
pub use runtime::ConsoleRestJsonResponse;
pub use runtime::DecisionRuntimeError;
pub use runtime::ElephantMemoryBackendConfig;
pub use runtime::ElephantMemoryStoreError;
pub use runtime::GatingAuditEntry;
pub use runtime::GatingDecideError;
pub use runtime::GatingDecideRequest;
pub use runtime::GatingDecision;
pub use runtime::GatingDecisionResult;
pub use runtime::GatingEvaluateRequest;
pub use runtime::GatingEvaluateResult;
pub use runtime::GatingOutcome;
pub use runtime::GatingPendingEntry;
pub use runtime::GatingRiskTier;
pub use runtime::InMemoryMetadataStore;
pub use runtime::JsonFileSessionStore;
pub use runtime::JsonFileSessionStoreError;
pub use runtime::JsonStoreLockRecord;
pub use runtime::LifecycleEvent;
pub use runtime::LifecycleStage;
pub use runtime::LocalJsonMemoryBackendConfig;
pub use runtime::LocalJsonMemoryStoreError;
pub use runtime::McpBoundaryError;
pub use runtime::MemoryAssertion;
pub use runtime::MemoryBackendConfig;
pub use runtime::MemoryConflictSignal;
pub use runtime::MemoryIndexError;
pub use runtime::MemoryIndexRequest;
pub use runtime::MemoryIndexResult;
pub use runtime::MemoryQueryRequest;
pub use runtime::MemoryQueryResult;
pub use runtime::MemoryStoreInfo;
pub use runtime::MetadataScope;
pub use runtime::MetadataStoreError;
pub use runtime::MobkitRuntimeError;
pub use runtime::MobkitRuntimeHandle;
pub use runtime::ModuleHealthState;
pub use runtime::ModuleHealthTransition;
pub use runtime::ModuleRouteError;
pub use runtime::ModuleRouteRequest;
pub use runtime::ModuleRouteResponse;
pub use runtime::NormalizationError;
pub use runtime::PersistentMetadataStore;
pub use runtime::RpcRouteError;
pub use runtime::RpcRuntimeError;
pub use runtime::RuntimeBoundaryError;
pub use runtime::RuntimeDecisionInputs;
pub use runtime::RuntimeDecisionState;
pub use runtime::RuntimeFromConfigError;
pub use runtime::RuntimeMetadataTable;
pub use runtime::RuntimeMutationError;
pub use runtime::RuntimeOptions;
pub use runtime::RuntimeRoute;
pub use runtime::RuntimeRouteMutationError;
pub use runtime::RuntimeShutdownReport;
pub use runtime::ScheduleDefinition;
pub use runtime::ScheduleDispatch;
pub use runtime::ScheduleDispatchReport;
pub use runtime::ScheduleEvaluation;
pub use runtime::ScheduleRuntimeInjection;
pub use runtime::ScheduleTrigger;
pub use runtime::SchedulingSupervisorSignal;
pub use runtime::SessionPersistenceRow;
pub use runtime::SessionStoreContract;
pub use runtime::SessionStoreKind;
pub use runtime::SqliteMetadataStore;
pub use runtime::SubscribeRequest;
pub use runtime::SubscribeResponse;
pub use runtime::SubscribeScope;
pub use runtime::SupervisorReport;
pub use runtime::TrustedOidcRuntimeConfig;
pub use runtime::WILDCARD_ROUTE;
pub use runtime::build_runtime_decision_state;
pub use runtime::evaluate_schedules_at_tick;
pub use runtime::handle_console_rest_json_route;
pub use runtime::handle_console_rest_json_route_with_snapshot;
pub use runtime::handle_console_rest_json_route_with_snapshot_and_access;
pub use runtime::materialize_latest_session_rows;
pub use runtime::materialize_live_session_rows;
pub use runtime::normalize_event_line;
pub use runtime::route_module_call;
pub use runtime::route_module_call_rpc_json;
pub use runtime::route_module_call_rpc_subprocess;
pub use runtime::run_discovered_module_once;
pub use runtime::run_meerkat_baseline_verification_once;
pub use runtime::run_module_boundary_once;
pub use runtime::run_rpc_capabilities_boundary_once;
pub use runtime::session_store_contracts;
pub use runtime::start_mobkit_runtime;
pub use runtime::start_mobkit_runtime_with_options;
pub use topology_control::SameProcessTopologyCoordinator;
pub use topology_control::TopologyAction;
pub use topology_control::TopologyApplyRequest;
pub use topology_control::TopologyBilateralApplyRequest;
pub use topology_control::TopologyBilateralPlan;
pub use topology_control::TopologyBilateralPlanRequest;
pub use topology_control::TopologyBilateralSnapshot;
pub use topology_control::TopologyBootstrapConfig;
pub use topology_control::TopologyControlError;
pub use topology_control::TopologyControlMode;
pub use topology_control::TopologyControlPolicy;
pub use topology_control::TopologyController;
pub use topology_control::TopologyEdge;
pub use topology_control::TopologyEdgeResult;
pub use topology_control::TopologyEdgeResultStatus;
pub use topology_control::TopologyEdgeSnapshot;
pub use topology_control::TopologyEndpoint;
pub use topology_control::TopologyMutation;
pub use topology_control::TopologyNodeAffordances;
pub use topology_control::TopologyNodeSnapshot;
pub use topology_control::TopologyOperationReceipt;
pub use topology_control::TopologyOperationRecord;
pub use topology_control::TopologyOperationRecordStatus;
pub use topology_control::TopologyOperationStatus;
pub use topology_control::TopologyPlan;
pub use topology_control::TopologyPlanRequest;
pub use topology_control::TopologyPlannedEdge;
pub use topology_control::TopologyRevisionTransition;
pub use topology_control::TopologyRuntimeHandle;
pub use topology_control::TopologySnapshot;
pub use types::AgentDiscoverySpec;
pub use types::DiscoverySpec;
pub use types::EventEnvelope;
pub use types::MobKitConfig;
pub use types::MobStructuralEventEnvelope;
pub use types::ModuleConfig;
pub use types::ModuleEvent;
pub use types::PreSpawnData;
pub use types::RestartPolicy;
pub use types::UnifiedEvent;
pub use unified_runtime::DEFAULT_REFERENCE_APP_MAX_CONCURRENT_REQUESTS;
pub use unified_runtime::DesiredPeerEdge;
pub use unified_runtime::DesiredPeerEdgeError;
pub use unified_runtime::Discovery;
pub use unified_runtime::EdgeDiscovery;
pub use unified_runtime::EdgeReconcileFailure;
pub use unified_runtime::ErrorEvent;
pub use unified_runtime::ErrorHook;
pub use unified_runtime::EventLogConfig;
pub use unified_runtime::EventLogStore;
pub use unified_runtime::EventQuery;
pub use unified_runtime::IdentityBootstrapMode;
pub use unified_runtime::PersistedEvent;
pub use unified_runtime::PostReconcileHook;
pub use unified_runtime::PostSpawnHook;
pub use unified_runtime::PreSpawnContext;
pub use unified_runtime::PreSpawnHook;
pub use unified_runtime::RediscoverReport;
pub use unified_runtime::ShutdownDrainReport;
pub use unified_runtime::UnifiedRuntime;
pub use unified_runtime::UnifiedRuntimeBootstrapError;
pub use unified_runtime::UnifiedRuntimeBuilder;
pub use unified_runtime::UnifiedRuntimeBuilderError;
pub use unified_runtime::UnifiedRuntimeBuilderField;
pub use unified_runtime::UnifiedRuntimeError;
pub use unified_runtime::UnifiedRuntimeReconcileEdgesReport;
pub use unified_runtime::UnifiedRuntimeReconcileError;
pub use unified_runtime::UnifiedRuntimeReconcileReport;
pub use unified_runtime::UnifiedRuntimeReconcileRoutingReport;
pub use unified_runtime::UnifiedRuntimeRunReport;
pub use unified_runtime::UnifiedRuntimeShutdownReport;
pub use unified_runtime::discovery_spec_to_spawn_spec;

Modules

access
Optional attribute-based access control (ABAC) for MobKit surfaces.
auth
JWT validation, JWKS caching, and OIDC discovery for API authentication.
baseline
Baseline runtime configuration and module bootstrapping.
blob_store
MobKit-owned binary blob storage.
config_convention
Convention-based config discovery for MobKit applications.
console_aggregator
console_config
Console UI configuration loaded from application config.
console_contracts
Console-facing contract types for the planned identity-native operator workbench.
contact_directory
Contact directory — maps mob IDs to transport info for cross-mob communication.
decisions
Policy decision framework — auth, console access, metrics, and runtime ops.
gateway_wiring
Shared gateway construction seams (doctrine D2: converge construction, merge binaries later).
governance
Governance validation for runtime configuration and deployment policies.
http_auth
HTTP middleware for Bearer token authentication using JWT/JWKS.
http_console
HTTP routes for the admin console REST API.
http_flow_editor
http_sse
Server-Sent Events (SSE) streaming endpoints for agent and mob observation.
identity_first
Identity-first continuity types and contracts for MobKit.
live_wiring
Live (realtime) member sessions through the mobkit gateways.
member_comms_id
Single owner of the mapping between MobKit’s public member aliases and the mob-roster member ids handed to meerkat-mob.
memory
MobKit agent-memory record layer (docs/design/agent-memory-architecture.md).
memory_wiring
Reusable assembly for the FULL agent-memory stack (6 architecture): the bundled SQLite store with the 10.1 taint firewall, plus the judgment plane (Distiller, Steward) and the member-event observer feeding them.
mob_handle_runtime
Mob member lifecycle management — bootstrap, spawn, reconcile, and roster queries.
mobpack
Mobpack authoring contract used by the bundled Flow Editor.
mocks
Test doubles and mock implementations for development and testing.
process
Process boundary types for gateway binary communication.
protocol
Wire protocol parsing for the gateway RPC transport.
rpc
JSON-RPC request handling for both module-only and unified runtime modes.
runtime
Runtime subsystem types — routing, delivery, gating, memory, scheduling, and session persistence.
schedule_wiring
Wire meerkat’s per-session schedule tools + firing host into the gateways.
tool_compose
Composition for external-tool dispatchers.
topology_control
Optional, policy-gated topology control plane.
types
Core type definitions shared across the MobKit runtime.
unified_runtime
Unified runtime — combines mob lifecycle, module management, and operational subsystems.
workgraph_admission
Shared admission control for WorkGraph attention-binding mutations.
workgraph_wiring
Wire meerkat’s WorkGraph (goals, work items, attention bindings and apply-time attention overlays) into the gateways.